@@ -202,7 +202,7 @@ switchColNames <- function(format=c("BED", "GFF",
 #'
 #'   macs <- system.file("extdata", "MACS_peaks.xls", package="ChIPpeakAnno")
 #'   macsOutput <- toGRanges(macs, format="MACS")
-#'   if(interactive() || Sys.getenv("USER")=="jianhongou"){
+#'   if(interactive() || Sys.getenv("USER")=="jou"){
 #'     ## MACS connection
 #'     macs <- readLines(macs)
 #'     macs <- textConnection(macs)
@@ -314,7 +314,7 @@ setMethod("toGRanges", "connection",
 setMethod("toGRanges", "TxDb",
           function(data, feature=c("gene", "transcript", "exon",
                                    "CDS", "fiveUTR", "threeUTR",
-                                   "microRNA", "tRNAs", "geneModel"),
+                                   "tRNAs", "geneModel"),
                    OrganismDb, ...){
               feature <- match.arg(feature)
               if(!missing(OrganismDb)) {
